@@ -279,4 +279,12 @@ class SeleniumDriver(BaseDriver):
                 row.append(cell)
             rows.append(row)
 
-        return rows
\ No newline at end of file
+        return rows
+    
+    def __str__(self):
+        return self.__unicode__()
+    
+    def __unicode__(self):
+        return "SeleniumDriver at '%s:%s' using '%s' browser." % (self.context.settings.extra_args.get("selenium.server", "localhost"),
+                self.context.settings.extra_args.get("selenium.port", 4444),
+                self.context.settings.browser_to_run)
\ No newline at end of file
